==> operation-prime-2.0.1-20140325.115143-8-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/ValidateDataset.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.Collections;
import java.util.List;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.metadata.NoSuchMetadataException;
import org.gcube.data.analysis.tabulardata.model.metadata.common.Validation;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ValidationsMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.worker.ImmutableWorkerResult;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.WorkerResult;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.WorkerException;

public class ValidateDataset extends Worker {

	private CubeManager cube;
	
	
	
	
	public ValidateDataset(OperationInvocation sourceInvocation,
			CubeManager cube) {
		super(sourceInvocation);
		this.cube = cube;
	}




	@Override
	protected WorkerResult execute() throws WorkerException {
		Table targetTable=cube.getTable(getSourceInvocation().getTargetTableId());		
		Validation toSet=new Validation("The table is a valid dataset", true);
		ValidationsMetadata meta=null;
		try{
			meta=targetTable.getMetadata(ValidationsMetadata.class);
			List<Validation>  previousValidations=meta.getValidations();
			previousValidations.add(toSet);
			meta=new ValidationsMetadata(previousValidations);
		}catch(NoSuchMetadataException e){
			meta=new ValidationsMetadata(Collections.singletonList(toSet));
		}
		return new ImmutableWorkerResult(cube.modifyTableMeta(getSourceInvocation().getTargetTableId()).setTableMetadata(meta).create());		
	}

}

==> operation-prime-2.0.3-20140326.145520-1-sources.jar: org/gcube/data/analysis/tabulardata/operation/validation/ValidateDataset.java <==
package org.gcube.data.analysis.tabulardata.operation.validation;

import java.util.Collections;
import java.util.List;

import org.gcube.data.analysis.tabulardata.cube.CubeManager;
import org.gcube.data.analysis.tabulardata.metadata.NoSuchMetadataException;
import org.gcube.data.analysis.tabulardata.model.metadata.common.Validation;
import org.gcube.data.analysis.tabulardata.model.metadata.common.ValidationsMetadata;
import org.gcube.data.analysis.tabulardata.model.table.Table;
import org.gcube.data.analysis.tabulardata.operation.invocation.OperationInvocation;
import org.gcube.data.analysis.tabulardata.operation.worker.ImmutableWorkerResult;
import org.gcube.data.analysis.tabulardata.operation.worker.Worker;
import org.gcube.data.analysis.tabulardata.operation.worker.WorkerResult;
import org.gcube.data.analysis.tabulardata.operation.worker.exceptions.WorkerException;

public class ValidateDataset extends Worker {

	private CubeManager cube;
	
	
	
	
	public ValidateDataset(OperationInvocation sourceInvocation,
			CubeManager cube) {
		super(sourceInvocation);
		this.cube = cube;
	}

	Table targetTable;


	@Override
	protected WorkerResult execute() throws WorkerException {
		targetTable=cube.getTable(getSourceInvocation().getTargetTableId());
		
		//check Allowed Column types
		//check one or 2 measures
		// validate dimension
		// set validations
		
		
		
		
		Validation toSet=new Validation("The table is a valid dataset", true);
		ValidationsMetadata meta=null;
		try{
			meta=targetTable.getMetadata(ValidationsMetadata.class);
			List<Validation>  previousValidations=meta.getValidations();
			previousValidations.add(toSet);
			meta=new ValidationsMetadata(previousValidations);
		}catch(NoSuchMetadataException e){
			meta=new ValidationsMetadata(Collections.singletonList(toSet));
		}
		return new ImmutableWorkerResult(cube.modifyTableMeta(getSourceInvocation().getTargetTableId()).setTableMetadata(meta).create());		
	}

}
